@@ -908,8 +908,8 @@ class FeedingIt:
         # If no internet connection, try again in 10 minutes:
         # gobject.timeout_add(int(5*3600000), self.automaticUpdate)
         file = open("/home/user/.feedingit/feedingit_widget.log", "a")
-        from time import gmtime, strftime
-        file.write("App: %s\n" % strftime("%a, %d %b %Y %H:%M:%S +0000", time()))
+        from time import localtime, strftime
+        file.write("App: %s\n" % strftime("%a, %d %b %Y %H:%M:%S +0000", localtime()))
         file.close()
         self.button_update_clicked(None, None)
         return True
